@@ -157,6 +157,8 @@ pub struct Config {
     pub hide_cursor_when_typing: bool,
     #[serde(default = "Renderer::default")]
     pub renderer: Renderer,
+    #[serde(default = "bool::default", rename = "draw-bold-text-with-light-colors")]
+    pub draw_bold_text_with_light_colors: bool,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
@@ -172,15 +174,23 @@ pub struct CursorConfig {
 #[cfg(not(target_os = "windows"))]
 #[inline]
 pub fn config_dir_path() -> PathBuf {
-    let home_dir = dirs::home_dir().unwrap();
-    home_dir.join(".config").join("rio")
+    std::env::var("RIO_CONFIG_HOME")
+        .map(PathBuf::from)
+        .unwrap_or(dirs::home_dir().unwrap().join(".config").join("rio"))
 }
 
 #[cfg(target_os = "windows")]
 #[inline]
 pub fn config_dir_path() -> PathBuf {
-    let home_dir = dirs::home_dir().unwrap();
-    home_dir.join("AppData").join("Local").join("rio")
+    std::env::var("RIO_CONFIG_HOME")
+        .map(PathBuf::from)
+        .unwrap_or(
+            dirs::home_dir()
+                .unwrap()
+                .join("AppData")
+                .join("Local")
+                .join("rio"),
+        )
 }
 
 #[inline]
@@ -504,6 +514,7 @@ impl Default for Config {
             ignore_selection_fg_color: false,
             confirm_before_quit: true,
             hide_cursor_when_typing: false,
+            draw_bold_text_with_light_colors: false,
         }
     }
 }
@@ -523,6 +534,7 @@ mod tests {
     use super::*;
     use colors::{hex_to_color_arr, hex_to_color_wgpu};
     use std::io::Write;
+    use sugarloaf::font::fonts::parse_unicode;
 
     fn tmp_dir() -> PathBuf {
         std::env::temp_dir()
@@ -950,24 +962,6 @@ mod tests {
         assert_eq!(result.colors.tabs, hex_to_color_arr("#030303"));
         assert_eq!(result.colors.white, hex_to_color_arr("#000000"));
         assert_eq!(result.colors.yellow, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_black, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_blue, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_cyan, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_foreground, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_green, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_magenta, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_red, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_white, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_yellow, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_black, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_blue, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_cyan, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_foreground, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_green, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_magenta, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_red, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_white, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_yellow, hex_to_color_arr("#030303"));
         assert_eq!(
             result.colors.selection_background,
             hex_to_color_arr("#111111")
@@ -1056,4 +1050,35 @@ mod tests {
         assert_eq!(result.colors.tabs_active, colors::defaults::tabs_active());
         assert_eq!(result.colors.cursor, colors::defaults::cursor());
     }
+
+    #[test]
+    fn test_symbol_map() {
+        let result = create_temporary_config(
+            "symbol-map",
+            r#"
+            fonts.symbol-map = [
+                # covers: '⊗','⊘','⊙'
+                { start = "2297", end = "2299", font-family = "PowerlineSymbols" },
+                { start = "E0C0", end = "E0C7", font-family = "Cascadia Code NF" },
+            ]
+        "#,
+        );
+
+        assert!(result.fonts.symbol_map.is_some());
+        let symbol_map = result.fonts.symbol_map.unwrap();
+        assert_eq!(symbol_map.len(), 2);
+        assert_eq!(symbol_map[0].font_family, "PowerlineSymbols");
+        assert_eq!(symbol_map[0].start, "2297");
+        assert_eq!(symbol_map[0].end, "2299");
+
+        assert_eq!(parse_unicode(&symbol_map[0].start), Some('\u{2297}'));
+        assert_eq!(parse_unicode(&symbol_map[0].end), Some('\u{2299}'));
+
+        assert_eq!(symbol_map[1].font_family, "Cascadia Code NF");
+        assert_eq!(symbol_map[1].start, "E0C0");
+        assert_eq!(symbol_map[1].end, "E0C7");
+
+        assert_eq!(parse_unicode(&symbol_map[1].start), Some('\u{E0C0}'));
+        assert_eq!(parse_unicode(&symbol_map[1].end), Some('\u{E0C7}'));
+    }
 }
