@@ -6,7 +6,6 @@ use crate::components::core::{image::Handle, shapes::Rectangle};
 use crate::components::filters::{Filter, FiltersBrush};
 use crate::components::layer::{self, LayerBrush};
 use crate::components::quad::QuadBrush;
-use crate::components::rect::{Rect, RectBrush};
 use crate::components::rich_text::RichTextBrush;
 use crate::font::{fonts::SugarloafFont, FontLibrary};
 use crate::layout::{RichTextLayout, RootStyle};
@@ -24,10 +23,9 @@ use state::SugarState;
 
 pub struct Sugarloaf<'a> {
     pub ctx: Context<'a>,
-    rect_brush: RectBrush,
     quad_brush: QuadBrush,
-    layer_brush: LayerBrush,
     rich_text_brush: RichTextBrush,
+    layer_brush: LayerBrush,
     state: state::SugarState,
     pub background_color: Option<wgpu::Color>,
     pub background_image: Option<ImageProperties>,
@@ -122,7 +120,6 @@ impl Sugarloaf<'_> {
         let font_features = renderer.font_features.to_owned();
         let ctx = Context::new(window, renderer);
 
-        let rect_brush = RectBrush::init(&ctx);
         let layer_brush = LayerBrush::new(&ctx);
         let quad_brush = QuadBrush::new(&ctx);
         let rich_text_brush = RichTextBrush::new(&ctx);
@@ -136,7 +133,6 @@ impl Sugarloaf<'_> {
             ctx,
             background_color: Some(wgpu::Color::BLACK),
             background_image: None,
-            rect_brush,
             rich_text_brush,
             graphics: Graphics::default(),
             filters_brush,
@@ -309,6 +305,9 @@ impl Sugarloaf<'_> {
         }
     }
 
+    #[inline]
+    pub fn add_layers(&mut self, _quantity: usize) {}
+
     #[inline]
     pub fn reset(&mut self) {
         self.state.reset();
@@ -317,10 +316,8 @@ impl Sugarloaf<'_> {
     #[inline]
     pub fn render(&mut self) {
         self.state.compute_dimensions(&mut self.rich_text_brush);
-
         self.state.compute_updates(
             &mut self.rich_text_brush,
-            &mut self.rect_brush,
             &mut self.quad_brush,
             &mut self.ctx,
             &mut self.graphics,
@@ -400,9 +397,6 @@ impl Sugarloaf<'_> {
                     self.quad_brush
                         .render(&mut self.ctx, &self.state, &mut rpass);
 
-                    self.rect_brush
-                        .render(&mut rpass, &self.state, &mut self.ctx);
-
                     self.rich_text_brush.render(&mut self.ctx, &mut rpass);
                 }
 
